@@ -474,7 +474,7 @@ class Wizard(object):
 
     def view_obj(self, model, args):
         for key, value in args.items():
-            obj_view = model()
+            obj_view = model(**args)
             if isinstance(value, dict):
                 field = getattr(model, key)
                 SubModel = self.pool.get(field.model_name)
@@ -488,13 +488,13 @@ class Wizard(object):
         user = ctx.get('user', None)
         with Transaction().start(self.db, user=user, context=ctx):
             session_id, start_state, end_state = self.wizard.create()
-            _self_wiz = self.wizard(session_id)
+            self_wiz = self.wizard(session_id)
             args = view.get(start_state)
-            _model = getattr(_self_wiz, start_state)
-            name_model = type(_model).__name__
+            ModelStart = getattr(self_wiz, start_state)
+            name_model = type(ModelStart).__name__
             model_view = self.pool.get(name_model)
-            setattr(_self_wiz, start_state, self.view_obj(model_view, args))
-            method = getattr(_self_wiz, method)
+            setattr(self_wiz, start_state, self.view_obj(model_view, args))
+            method = getattr(self_wiz, method)
             result = method()
             return result
 
